# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictStr
from typing import Any, Optional
from flowhunt.models.user_response import UserResponse

from flowhunt.api_client import ApiClient, RequestSerialized
from flowhunt.api_response import ApiResponse
from flowhunt.rest import RESTResponseType


class WebAuthApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def activate_account(
        self,
        token: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Activate Account

        Activate user account

        :param token: (required)
        :type token: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._activate_account_serialize(
            token=token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def activate_account_with_http_info(
        self,
        token: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Activate Account

        Activate user account

        :param token: (required)
        :type token: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._activate_account_serialize(
            token=token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def activate_account_without_preload_content(
        self,
        token: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Activate Account

        Activate user account

        :param token: (required)
        :type token: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._activate_account_serialize(
            token=token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _activate_account_serialize(
        self,
        token,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/auth/activate',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_user(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserResponse:
        """Get User

        Get current authenticated user details.  This endpoint returns the current user's details including their product plans and API key workspace information. It follows DDD principles by delegating the business logic to the application service layer.  Args:     user: The current authenticated user (injected by dependency)     request: The HTTP request object     user_service: The user application service (injected by dependency)  Returns:     UserResponse: The user details response

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_user_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_user_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserResponse]:
        """Get User

        Get current authenticated user details.  This endpoint returns the current user's details including their product plans and API key workspace information. It follows DDD principles by delegating the business logic to the application service layer.  Args:     user: The current authenticated user (injected by dependency)     request: The HTTP request object     user_service: The user application service (injected by dependency)  Returns:     UserResponse: The user details response

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_user_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_user_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get User

        Get current authenticated user details.  This endpoint returns the current user's details including their product plans and API key workspace information. It follows DDD principles by delegating the business logic to the application service layer.  Args:     user: The current authenticated user (injected by dependency)     request: The HTTP request object     user_service: The user application service (injected by dependency)  Returns:     UserResponse: The user details response

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_user_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_user_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader', 
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/auth/me',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def password_recovery_page(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Password Recovery Page

        Password recovery page

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._password_recovery_page_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def password_recovery_page_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Password Recovery Page

        Password recovery page

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._password_recovery_page_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def password_recovery_page_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Password Recovery Page

        Password recovery page

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._password_recovery_page_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _password_recovery_page_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/auth/recover-password',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def password_recovery_submit(
        self,
        email: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Password Recovery Submit

        Handle password recovery form submission

        :param email: (required)
        :type email: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._password_recovery_submit_serialize(
            email=email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def password_recovery_submit_with_http_info(
        self,
        email: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Password Recovery Submit

        Handle password recovery form submission

        :param email: (required)
        :type email: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._password_recovery_submit_serialize(
            email=email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def password_recovery_submit_without_preload_content(
        self,
        email: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Password Recovery Submit

        Handle password recovery form submission

        :param email: (required)
        :type email: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._password_recovery_submit_serialize(
            email=email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _password_recovery_submit_serialize(
        self,
        email,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if email is not None:
            _form_params.append(('email', email))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/auth/recover-password',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def register_page(
        self,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Register Page

        Registration page

        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._register_page_serialize(
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def register_page_with_http_info(
        self,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Register Page

        Registration page

        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._register_page_serialize(
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def register_page_without_preload_content(
        self,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Register Page

        Registration page

        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._register_page_serialize(
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _register_page_serialize(
        self,
        next,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if next is not None:
            
            _query_params.append(('next', next))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/auth/register',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def register_submit(
        self,
        name: StrictStr,
        email: StrictStr,
        password: StrictStr,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Register Submit

        Handle registration form submission

        :param name: (required)
        :type name: str
        :param email: (required)
        :type email: str
        :param password: (required)
        :type password: str
        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._register_submit_serialize(
            name=name,
            email=email,
            password=password,
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def register_submit_with_http_info(
        self,
        name: StrictStr,
        email: StrictStr,
        password: StrictStr,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Register Submit

        Handle registration form submission

        :param name: (required)
        :type name: str
        :param email: (required)
        :type email: str
        :param password: (required)
        :type password: str
        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._register_submit_serialize(
            name=name,
            email=email,
            password=password,
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def register_submit_without_preload_content(
        self,
        name: StrictStr,
        email: StrictStr,
        password: StrictStr,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Register Submit

        Handle registration form submission

        :param name: (required)
        :type name: str
        :param email: (required)
        :type email: str
        :param password: (required)
        :type password: str
        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._register_submit_serialize(
            name=name,
            email=email,
            password=password,
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _register_submit_serialize(
        self,
        name,
        email,
        password,
        next,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if name is not None:
            _form_params.append(('name', name))
        if email is not None:
            _form_params.append(('email', email))
        if password is not None:
            _form_params.append(('password', password))
        if next is not None:
            _form_params.append(('next', next))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/auth/register',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def reset_password_page(
        self,
        token: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Reset Password Page

        Reset password page

        :param token: (required)
        :type token: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reset_password_page_serialize(
            token=token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def reset_password_page_with_http_info(
        self,
        token: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Reset Password Page

        Reset password page

        :param token: (required)
        :type token: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reset_password_page_serialize(
            token=token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def reset_password_page_without_preload_content(
        self,
        token: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Reset Password Page

        Reset password page

        :param token: (required)
        :type token: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reset_password_page_serialize(
            token=token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reset_password_page_serialize(
        self,
        token,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/auth/reset-password',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def reset_password_submit(
        self,
        token: StrictStr,
        password: StrictStr,
        confirm_password: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Reset Password Submit

        Handle reset password form submission

        :param token: (required)
        :type token: str
        :param password: (required)
        :type password: str
        :param confirm_password: (required)
        :type confirm_password: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reset_password_submit_serialize(
            token=token,
            password=password,
            confirm_password=confirm_password,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def reset_password_submit_with_http_info(
        self,
        token: StrictStr,
        password: StrictStr,
        confirm_password: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Reset Password Submit

        Handle reset password form submission

        :param token: (required)
        :type token: str
        :param password: (required)
        :type password: str
        :param confirm_password: (required)
        :type confirm_password: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reset_password_submit_serialize(
            token=token,
            password=password,
            confirm_password=confirm_password,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def reset_password_submit_without_preload_content(
        self,
        token: StrictStr,
        password: StrictStr,
        confirm_password: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Reset Password Submit

        Handle reset password form submission

        :param token: (required)
        :type token: str
        :param password: (required)
        :type password: str
        :param confirm_password: (required)
        :type confirm_password: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reset_password_submit_serialize(
            token=token,
            password=password,
            confirm_password=confirm_password,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reset_password_submit_serialize(
        self,
        token,
        password,
        confirm_password,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if token is not None:
            _form_params.append(('token', token))
        if password is not None:
            _form_params.append(('password', password))
        if confirm_password is not None:
            _form_params.append(('confirm_password', confirm_password))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/auth/reset-password',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def sso_login_page(
        self,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Sso Login Page

        SSO login page

        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._sso_login_page_serialize(
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def sso_login_page_with_http_info(
        self,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Sso Login Page

        SSO login page

        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._sso_login_page_serialize(
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def sso_login_page_without_preload_content(
        self,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Sso Login Page

        SSO login page

        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._sso_login_page_serialize(
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _sso_login_page_serialize(
        self,
        next,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if next is not None:
            
            _query_params.append(('next', next))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/auth/oauth/sso',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def sso_login_submit(
        self,
        email: StrictStr,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Sso Login Submit

        Handle SSO login form submission

        :param email: (required)
        :type email: str
        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._sso_login_submit_serialize(
            email=email,
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def sso_login_submit_with_http_info(
        self,
        email: StrictStr,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Sso Login Submit

        Handle SSO login form submission

        :param email: (required)
        :type email: str
        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._sso_login_submit_serialize(
            email=email,
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def sso_login_submit_without_preload_content(
        self,
        email: StrictStr,
        next: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Sso Login Submit

        Handle SSO login form submission

        :param email: (required)
        :type email: str
        :param next:
        :type next: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._sso_login_submit_serialize(
            email=email,
            next=next,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _sso_login_submit_serialize(
        self,
        email,
        next,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if email is not None:
            _form_params.append(('email', email))
        if next is not None:
            _form_params.append(('next', next))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/auth/oauth/sso',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa
"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from flowhunt.models.all_flows_search_request import AllFlowsSearchRequest
from flowhunt.models.api_key_create_request import ApiKeyCreateRequest
from flowhunt.models.api_key_response import ApiKeyResponse
from flowhunt.models.api_key_search_request import ApiKeySearchRequest
from flowhunt.models.api_key_update_request import ApiKeyUpdateRequest
from flowhunt.models.app_url_input import AppUrlInput
from flowhunt.models.app_url_output import AppUrlOutput
from flowhunt.models.aspec_ratio import AspecRatio
from flowhunt.models.base_foundation_model import BaseFoundationModel
from flowhunt.models.bool_char import BoolChar
from flowhunt.models.chatbot_create_request import ChatbotCreateRequest
from flowhunt.models.chatbot_response import ChatbotResponse
from flowhunt.models.chatbot_search_request import ChatbotSearchRequest
from flowhunt.models.chatbot_status import ChatbotStatus
from flowhunt.models.chatbot_update_request import ChatbotUpdateRequest
from flowhunt.models.checkout_create_request import CheckoutCreateRequest
from flowhunt.models.community_image_generations_response import CommunityImageGenerationsResponse
from flowhunt.models.completed import Completed
from flowhunt.models.credit_balance_response import CreditBalanceResponse
from flowhunt.models.credit_daily_transaction_response import CreditDailyTransactionResponse
from flowhunt.models.credit_daily_transaction_search_request import CreditDailyTransactionSearchRequest
from flowhunt.models.credit_transaction_response import CreditTransactionResponse
from flowhunt.models.credit_transaction_search_request import CreditTransactionSearchRequest
from flowhunt.models.customer_data_request_payload import CustomerDataRequestPayload
from flowhunt.models.customer_redact_payload import CustomerRedactPayload
from flowhunt.models.data import Data
from flowhunt.models.document_category_create_request import DocumentCategoryCreateRequest
from flowhunt.models.document_category_response import DocumentCategoryResponse
from flowhunt.models.document_category_search_request import DocumentCategorySearchRequest
from flowhunt.models.document_category_update_request import DocumentCategoryUpdateRequest
from flowhunt.models.document_content import DocumentContent
from flowhunt.models.document_content_response import DocumentContentResponse
from flowhunt.models.document_response import DocumentResponse
from flowhunt.models.document_search_request import DocumentSearchRequest
from flowhunt.models.document_similarity_request import DocumentSimilarityRequest
from flowhunt.models.document_similarity_task_request import DocumentSimilarityTaskRequest
from flowhunt.models.document_status import DocumentStatus
from flowhunt.models.document_type import DocumentType
from flowhunt.models.document_update_request import DocumentUpdateRequest
from flowhunt.models.driver_success_response import DriverSuccessResponse
from flowhunt.models.driver_type import DriverType
from flowhunt.models.ft_status import FTStatus
from flowhunt.models.ft_type import FTType
from flowhunt.models.faq_create_request import FaqCreateRequest
from flowhunt.models.faq_response import FaqResponse
from flowhunt.models.faq_search_request import FaqSearchRequest
from flowhunt.models.faq_status import FaqStatus
from flowhunt.models.faq_type import FaqType
from flowhunt.models.faq_update_request import FaqUpdateRequest
from flowhunt.models.feature_response import FeatureResponse
from flowhunt.models.file_upload_response import FileUploadResponse
from flowhunt.models.flow_assistant_ai_model import FlowAssistantAIModel
from flowhunt.models.flow_assistant_add_component_metadata import FlowAssistantAddComponentMetadata
from flowhunt.models.flow_assistant_add_connection_metadata import FlowAssistantAddConnectionMetadata
from flowhunt.models.flow_assistant_apply_reject_changes_request import FlowAssistantApplyRejectChangesRequest
from flowhunt.models.flow_assistant_create_blank_flow_metadata import FlowAssistantCreateBlankFlowMetadata
from flowhunt.models.flow_assistant_delete_component_metadata import FlowAssistantDeleteComponentMetadata
from flowhunt.models.flow_assistant_delete_connection_metadata import FlowAssistantDeleteConnectionMetadata
from flowhunt.models.flow_assistant_invoke_request import FlowAssistantInvokeRequest
from flowhunt.models.flow_assistant_session_create_request import FlowAssistantSessionCreateRequest
from flowhunt.models.flow_assistant_update_component_metadata import FlowAssistantUpdateComponentMetadata
from flowhunt.models.flow_branch import FlowBranch
from flowhunt.models.flow_category_create_request import FlowCategoryCreateRequest
from flowhunt.models.flow_category_response import FlowCategoryResponse
from flowhunt.models.flow_category_search_request import FlowCategorySearchRequest
from flowhunt.models.flow_commit_request import FlowCommitRequest
from flowhunt.models.flow_commit_response import FlowCommitResponse
from flowhunt.models.flow_config import FlowConfig
from flowhunt.models.flow_create import FlowCreate
from flowhunt.models.flow_cron_create_request import FlowCronCreateRequest
from flowhunt.models.flow_cron_response import FlowCronResponse
from flowhunt.models.flow_cron_search_request import FlowCronSearchRequest
from flowhunt.models.flow_cron_status import FlowCronStatus
from flowhunt.models.flow_cron_update_request import FlowCronUpdateRequest
from flowhunt.models.flow_detail_response import FlowDetailResponse
from flowhunt.models.flow_event_action_type import FlowEventActionType
from flowhunt.models.flow_hunt_product_slug import FlowHuntProductSlug
from flowhunt.models.flow_invoke_request import FlowInvokeRequest
from flowhunt.models.flow_response import FlowResponse
from flowhunt.models.flow_search_request import FlowSearchRequest
from flowhunt.models.flow_session_attachment_response import FlowSessionAttachmentResponse
from flowhunt.models.flow_session_create_from_flow_request import FlowSessionCreateFromFlowRequest
from flowhunt.models.flow_session_create_request import FlowSessionCreateRequest
from flowhunt.models.flow_session_event import FlowSessionEvent
from flowhunt.models.flow_session_invocation_response import FlowSessionInvocationResponse
from flowhunt.models.flow_session_invoke_request import FlowSessionInvokeRequest
from flowhunt.models.flow_session_loading_metadata import FlowSessionLoadingMetadata
from flowhunt.models.flow_session_message_metadata import FlowSessionMessageMetadata
from flowhunt.models.flow_session_response import FlowSessionResponse
from flowhunt.models.flow_session_task_response_metadata import FlowSessionTaskResponseMetadata
from flowhunt.models.flow_session_tool_call_metadata import FlowSessionToolCallMetadata
from flowhunt.models.flow_session_view_response import FlowSessionViewResponse
from flowhunt.models.flow_session_view_search_request import FlowSessionViewSearchRequest
from flowhunt.models.flow_session_view_update_request import FlowSessionViewUpdateRequest
from flowhunt.models.flow_type import FlowType
from flowhunt.models.flow_update import FlowUpdate
from flowhunt.models.flow_version_history_response import FlowVersionHistoryResponse
from flowhunt.models.general_mcp_subserver_capabilities_response import GeneralMCPSubserverCapabilitiesResponse
from flowhunt.models.general_mcp_subserver_response import GeneralMCPSubserverResponse
from flowhunt.models.google_ads_action_type import GoogleAdsActionType
from flowhunt.models.google_ads_analyze_keywords_request import GoogleAdsAnalyzeKeywordsRequest
from flowhunt.models.google_ads_campaign_response import GoogleAdsCampaignResponse
from flowhunt.models.google_ads_campaign_status import GoogleAdsCampaignStatus
from flowhunt.models.google_ads_campaign_update_request import GoogleAdsCampaignUpdateRequest
from flowhunt.models.google_ads_campaigns_response import GoogleAdsCampaignsResponse
from flowhunt.models.google_ads_campaigns_search_request import GoogleAdsCampaignsSearchRequest
from flowhunt.models.google_ads_customer_response import GoogleAdsCustomerResponse
from flowhunt.models.google_ads_customer_update_request import GoogleAdsCustomerUpdateRequest
from flowhunt.models.google_ads_customers_response import GoogleAdsCustomersResponse
from flowhunt.models.google_ads_customers_search_request import GoogleAdsCustomersSearchRequest
from flowhunt.models.google_ads_group_response import GoogleAdsGroupResponse
from flowhunt.models.google_ads_group_status import GoogleAdsGroupStatus
from flowhunt.models.google_ads_group_update_request import GoogleAdsGroupUpdateRequest
from flowhunt.models.google_ads_groups_response import GoogleAdsGroupsResponse
from flowhunt.models.google_ads_groups_search_request import GoogleAdsGroupsSearchRequest
from flowhunt.models.google_ads_keyword_add_request import GoogleAdsKeywordAddRequest
from flowhunt.models.google_ads_keyword_recommendation import GoogleAdsKeywordRecommendation
from flowhunt.models.google_ads_keyword_remove_request import GoogleAdsKeywordRemoveRequest
from flowhunt.models.google_ads_match_type import GoogleAdsMatchType
from flowhunt.models.google_ads_recommendation import GoogleAdsRecommendation
from flowhunt.models.google_ads_recommendation_confidence import GoogleAdsRecommendationConfidence
from flowhunt.models.google_ads_recommendation_status import GoogleAdsRecommendationStatus
from flowhunt.models.google_ads_recommendation_type import GoogleAdsRecommendationType
from flowhunt.models.google_ads_recommendations_request import GoogleAdsRecommendationsRequest
from flowhunt.models.google_calendar_response import GoogleCalendarResponse
from flowhunt.models.google_calendars_response import GoogleCalendarsResponse
from flowhunt.models.google_picker_token_response import GooglePickerTokenResponse
from flowhunt.models.google_sheet_response import GoogleSheetResponse
from flowhunt.models.google_sheets_response import GoogleSheetsResponse
from flowhunt.models.http_validation_error import HTTPValidationError
from flowhunt.models.health import Health
from flowhunt.models.hub_spot_actor_id_response import HubSpotActorIdResponse
from flowhunt.models.hub_spot_actors_response import HubSpotActorsResponse
from flowhunt.models.image_convert_request import ImageConvertRequest
from flowhunt.models.image_ft_create_request import ImageFTCreateRequest
from flowhunt.models.image_ft_response import ImageFTResponse
from flowhunt.models.image_ft_search_request import ImageFTSearchRequest
from flowhunt.models.image_ft_update_request import ImageFTUpdateRequest
from flowhunt.models.image_inference_request import ImageInferenceRequest
from flowhunt.models.image_inference_response import ImageInferenceResponse
from flowhunt.models.image_inference_result_response import ImageInferenceResultResponse
from flowhunt.models.image_inference_schedule_response import ImageInferenceScheduleResponse
from flowhunt.models.image_inference_scroll_response import ImageInferenceScrollResponse
from flowhunt.models.image_optimize_request import ImageOptimizeRequest
from flowhunt.models.image_prompt_generation_request import ImagePromptGenerationRequest
from flowhunt.models.image_prompt_response import ImagePromptResponse
from flowhunt.models.inference_file_type import InferenceFileType
from flowhunt.models.inference_history_search_request import InferenceHistorySearchRequest
from flowhunt.models.instagram_profile_information_response import InstagramProfileInformationResponse
from flowhunt.models.integration_category import IntegrationCategory
from flowhunt.models.integration_detail_response import IntegrationDetailResponse
from flowhunt.models.integration_flow_response import IntegrationFlowResponse
from flowhunt.models.integration_response import IntegrationResponse
from flowhunt.models.integration_search_request import IntegrationSearchRequest
from flowhunt.models.integration_slug import IntegrationSlug
from flowhunt.models.langfuse_request import LangfuseRequest
from flowhunt.models.log_entry_level import LogEntryLevel
from flowhunt.models.log_entry_type import LogEntryType
from flowhunt.models.log_response import LogResponse
from flowhunt.models.logs_search_request import LogsSearchRequest
from flowhunt.models.mcp_capability_binding import MCPCapabilityBinding
from flowhunt.models.mcp_server_create_request import MCPServerCreateRequest
from flowhunt.models.mcp_server_response import MCPServerResponse
from flowhunt.models.mcp_server_search_request import MCPServerSearchRequest
from flowhunt.models.mcp_sub_server_binding import MCPSubServerBinding
from flowhunt.models.message_type import MessageType
from flowhunt.models.metadata import Metadata
from flowhunt.models.observability_driver_response import ObservabilityDriverResponse
from flowhunt.models.pagination import Pagination
from flowhunt.models.photo_ai_effect_response import PhotoAIEffectResponse
from flowhunt.models.photo_ai_style_response import PhotoAIStyleResponse
from flowhunt.models.photo_ai_template_response import PhotoAITemplateResponse
from flowhunt.models.plan_list_item_response import PlanListItemResponse
from flowhunt.models.plan_response import PlanResponse
from flowhunt.models.pointer_type import PointerType
from flowhunt.models.prompt_category_create_request import PromptCategoryCreateRequest
from flowhunt.models.prompt_category_response import PromptCategoryResponse
from flowhunt.models.prompt_category_search_request import PromptCategorySearchRequest
from flowhunt.models.prompt_category_update_request import PromptCategoryUpdateRequest
from flowhunt.models.prompt_create_request import PromptCreateRequest
from flowhunt.models.prompt_response import PromptResponse
from flowhunt.models.prompt_search_request import PromptSearchRequest
from flowhunt.models.prompt_update_request import PromptUpdateRequest
from flowhunt.models.query_similarity_request import QuerySimilarityRequest
from flowhunt.models.query_similarity_task_request import QuerySimilarityTaskRequest
from flowhunt.models.role import Role
from flowhunt.models.saml_login_method import SamlLoginMethod
from flowhunt.models.schedule_create_request import ScheduleCreateRequest
from flowhunt.models.schedule_frequency import ScheduleFrequency
from flowhunt.models.schedule_response import ScheduleResponse
from flowhunt.models.schedule_search_request import ScheduleSearchRequest
from flowhunt.models.schedule_status import ScheduleStatus
from flowhunt.models.schedule_type import ScheduleType
from flowhunt.models.schedule_update_request import ScheduleUpdateRequest
from flowhunt.models.schedule_url_detail_response import ScheduleUrlDetailResponse
from flowhunt.models.schedule_url_response import ScheduleUrlResponse
from flowhunt.models.schedule_url_search_request import ScheduleUrlSearchRequest
from flowhunt.models.screenshot_request import ScreenshotRequest
from flowhunt.models.screenshot_response import ScreenshotResponse
from flowhunt.models.secret_create_request import SecretCreateRequest
from flowhunt.models.secret_response import SecretResponse
from flowhunt.models.secret_search_request import SecretSearchRequest
from flowhunt.models.secret_update_request import SecretUpdateRequest
from flowhunt.models.serp_cluster_add_query_request import SerpClusterAddQueryRequest
from flowhunt.models.serp_cluster_add_query_requests import SerpClusterAddQueryRequests
from flowhunt.models.serp_cluster_best_groups_request import SerpClusterBestGroupsRequest
from flowhunt.models.serp_cluster_group_intersections_request import SerpClusterGroupIntersectionsRequest
from flowhunt.models.serp_cluster_group_search_request import SerpClusterGroupSearchRequest
from flowhunt.models.serp_cluster_group_sub_clusters_request import SerpClusterGroupSubClustersRequest
from flowhunt.models.serp_cluster_keyword_intersections_request import SerpClusterKeywordIntersectionsRequest
from flowhunt.models.serp_cluster_keyword_response import SerpClusterKeywordResponse
from flowhunt.models.serp_group_intersection import SerpGroupIntersection
from flowhunt.models.serp_keyword import SerpKeyword
from flowhunt.models.serp_keyword_relation import SerpKeywordRelation
from flowhunt.models.serp_query_request import SerpQueryRequest
from flowhunt.models.serp_search_engine_type import SerpSearchEngineType
from flowhunt.models.serp_search_request import SerpSearchRequest
from flowhunt.models.serp_search_requests import SerpSearchRequests
from flowhunt.models.serp_subcluster_keywords_response import SerpSubclusterKeywordsResponse
from flowhunt.models.serp_volume_request import SerpVolumeRequest
from flowhunt.models.shop_redact_payload import ShopRedactPayload
from flowhunt.models.slack_channel_response import SlackChannelResponse
from flowhunt.models.slack_workspace_response import SlackWorkspaceResponse
from flowhunt.models.sort_direction import SortDirection
from flowhunt.models.subscription_plan import SubscriptionPlan
from flowhunt.models.tag_create_request import TagCreateRequest
from flowhunt.models.tag_response import TagResponse
from flowhunt.models.tag_search_request import TagSearchRequest
from flowhunt.models.tag_update_request import TagUpdateRequest
from flowhunt.models.task_response import TaskResponse
from flowhunt.models.task_status import TaskStatus
from flowhunt.models.tracking_click_id_names import TrackingClickIdNames
from flowhunt.models.tracking_event_create_request import TrackingEventCreateRequest
from flowhunt.models.tracking_event_create_requests import TrackingEventCreateRequests
from flowhunt.models.tracking_event_data import TrackingEventData
from flowhunt.models.tracking_event_response import TrackingEventResponse
from flowhunt.models.tracking_event_search_request import TrackingEventSearchRequest
from flowhunt.models.tracking_events_response import TrackingEventsResponse
from flowhunt.models.tracking_link_create_request import TrackingLinkCreateRequest
from flowhunt.models.tracking_link_response import TrackingLinkResponse
from flowhunt.models.tracking_link_search_request import TrackingLinkSearchRequest
from flowhunt.models.tracking_links_create_request import TrackingLinksCreateRequest
from flowhunt.models.tracking_links_response import TrackingLinksResponse
from flowhunt.models.tracking_source_create_request import TrackingSourceCreateRequest
from flowhunt.models.tracking_source_response import TrackingSourceResponse
from flowhunt.models.tracking_source_search_request import TrackingSourceSearchRequest
from flowhunt.models.tracking_source_types import TrackingSourceTypes
from flowhunt.models.tracking_sources_response import TrackingSourcesResponse
from flowhunt.models.transaction_type import TransactionType
from flowhunt.models.transcript_task_request import TranscriptTaskRequest
from flowhunt.models.trigger_response import TriggerResponse
from flowhunt.models.trigger_type import TriggerType
from flowhunt.models.url_screenshot_response import UrlScreenshotResponse
from flowhunt.models.user_document_status import UserDocumentStatus
from flowhunt.models.user_plan_response import UserPlanResponse
from flowhunt.models.user_response import UserResponse
from flowhunt.models.validation_error import ValidationError
from flowhunt.models.validation_error_loc_inner import ValidationErrorLocInner
from flowhunt.models.vector_document_response import VectorDocumentResponse
from flowhunt.models.vector_document_type import VectorDocumentType
from flowhunt.models.vector_documents_task_response import VectorDocumentsTaskResponse
from flowhunt.models.word_press_category_response import WordPressCategoryResponse
from flowhunt.models.word_press_site_response import WordPressSiteResponse
from flowhunt.models.word_press_tags_response import WordPressTagsResponse
from flowhunt.models.workspace_create_request import WorkspaceCreateRequest
from flowhunt.models.workspace_response import WorkspaceResponse
from flowhunt.models.workspace_role import WorkspaceRole
from flowhunt.models.workspace_sso_create_request import WorkspaceSSOCreateRequest
from flowhunt.models.workspace_sso_domain_verification_create_request import WorkspaceSSODomainVerificationCreateRequest
from flowhunt.models.workspace_sso_domain_verification_response import WorkspaceSSODomainVerificationResponse
from flowhunt.models.workspace_sso_list_response import WorkspaceSSOListResponse
from flowhunt.models.workspace_sso_response import WorkspaceSSOResponse
from flowhunt.models.workspace_sso_update_request import WorkspaceSSOUpdateRequest
from flowhunt.models.workspace_search_request import WorkspaceSearchRequest
from flowhunt.models.workspace_update_request import WorkspaceUpdateRequest
from flowhunt.models.workspace_user_create_request import WorkspaceUserCreateRequest
from flowhunt.models.workspace_user_response import WorkspaceUserResponse
from flowhunt.models.workspace_user_update_request import WorkspaceUserUpdateRequest
from flowhunt.models.workspace_users_search_request import WorkspaceUsersSearchRequest
from flowhunt.models.youtube_content import YoutubeContent
from flowhunt.models.youtube_transcript_request import YoutubeTranscriptRequest
from flowhunt.models.youtube_transcript_response import YoutubeTranscriptResponse



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.photo_ai_api import PhotoAIApi


class TestPhotoAIApi(unittest.TestCase):
    """PhotoAIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PhotoAIApi()

    def tearDown(self) -> None:
        pass

    def test_explore(self) -> None:
        """Test case for explore

        Explore
        """
        pass

    def test_get_effects(self) -> None:
        """Test case for get_effects

        Get Effects
        """
        pass

    def test_get_styles(self) -> None:
        """Test case for get_styles

        Get Styles
        """
        pass

    def test_get_templates(self) -> None:
        """Test case for get_templates

        Get Templates
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.o_auth_api import OAuthApi


class TestOAuthApi(unittest.TestCase):
    """OAuthApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OAuthApi()

    def tearDown(self) -> None:
        pass

    def test_oauth_authorize(self) -> None:
        """Test case for oauth_authorize

        Oauth Authorize
        """
        pass

    def test_oauth_authorize_post(self) -> None:
        """Test case for oauth_authorize_post

        Oauth Authorize Post
        """
        pass

    def test_oauth_callback(self) -> None:
        """Test case for oauth_callback

        Oauth Callback
        """
        pass

    def test_oauth_login(self) -> None:
        """Test case for oauth_login

        Oauth Login
        """
        pass

    def test_oauth_login_github(self) -> None:
        """Test case for oauth_login_github

        Oauth Login Github
        """
        pass

    def test_oauth_login_google(self) -> None:
        """Test case for oauth_login_google

        Oauth Login Google
        """
        pass

    def test_oauth_login_post(self) -> None:
        """Test case for oauth_login_post

        Oauth Login Post
        """
        pass

    def test_oauth_login_shopify(self) -> None:
        """Test case for oauth_login_shopify

        Oauth Login Shopify
        """
        pass

    def test_oauth_logout(self) -> None:
        """Test case for oauth_logout

        Oauth Logout
        """
        pass

    def test_oauth_revoke(self) -> None:
        """Test case for oauth_revoke

        Oauth Revoke
        """
        pass

    def test_oauth_token(self) -> None:
        """Test case for oauth_token

        Oauth Token
        """
        pass

    def test_oauth_userinfo(self) -> None:
        """Test case for oauth_userinfo

        Oauth Userinfo
        """
        pass

    def test_saml_callback(self) -> None:
        """Test case for saml_callback

        Saml Callback
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.serp_volume_request import SerpVolumeRequest

class TestSerpVolumeRequest(unittest.TestCase):
    """SerpVolumeRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SerpVolumeRequest:
        """Test SerpVolumeRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SerpVolumeRequest`
        """
        model = SerpVolumeRequest()
        if include_optional:
            return SerpVolumeRequest(
                post_back_url = '',
                keywords = [
                    ''
                    ],
                language_code = '',
                location_name = '',
                include_adult_keywords = True,
                date_from = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                date_to = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date()
            )
        else:
            return SerpVolumeRequest(
                keywords = [
                    ''
                    ],
        )
        """

    def testSerpVolumeRequest(self):
        """Test SerpVolumeRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class FlowSessionViewResponse(BaseModel):
    """
    FlowSessionViewResponse
    """ # noqa: E501
    session_id: StrictStr = Field(description="Session ID")
    chatbot_id: Optional[StrictStr] = None
    flow_id: StrictStr = Field(description="Flow ID")
    workspace_id: StrictStr = Field(description="Workspace ID")
    created_at: datetime = Field(description="Created at")
    last_msg_at: Optional[datetime] = None
    msg_count: Optional[StrictInt] = None
    credits: Optional[StrictInt] = None
    chatbot_name: Optional[StrictStr] = None
    flow_name: Optional[StrictStr] = None
    tags: Optional[List[StrictStr]] = None
    duration: Optional[StrictInt] = None
    ipaddress: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["session_id", "chatbot_id", "flow_id", "workspace_id", "created_at", "last_msg_at", "msg_count", "credits", "chatbot_name", "flow_name", "tags", "duration", "ipaddress", "url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FlowSessionViewResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if chatbot_id (nullable) is None
        # and model_fields_set contains the field
        if self.chatbot_id is None and "chatbot_id" in self.model_fields_set:
            _dict['chatbot_id'] = None

        # set to None if last_msg_at (nullable) is None
        # and model_fields_set contains the field
        if self.last_msg_at is None and "last_msg_at" in self.model_fields_set:
            _dict['last_msg_at'] = None

        # set to None if msg_count (nullable) is None
        # and model_fields_set contains the field
        if self.msg_count is None and "msg_count" in self.model_fields_set:
            _dict['msg_count'] = None

        # set to None if credits (nullable) is None
        # and model_fields_set contains the field
        if self.credits is None and "credits" in self.model_fields_set:
            _dict['credits'] = None

        # set to None if chatbot_name (nullable) is None
        # and model_fields_set contains the field
        if self.chatbot_name is None and "chatbot_name" in self.model_fields_set:
            _dict['chatbot_name'] = None

        # set to None if flow_name (nullable) is None
        # and model_fields_set contains the field
        if self.flow_name is None and "flow_name" in self.model_fields_set:
            _dict['flow_name'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if duration (nullable) is None
        # and model_fields_set contains the field
        if self.duration is None and "duration" in self.model_fields_set:
            _dict['duration'] = None

        # set to None if ipaddress (nullable) is None
        # and model_fields_set contains the field
        if self.ipaddress is None and "ipaddress" in self.model_fields_set:
            _dict['ipaddress'] = None

        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FlowSessionViewResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "session_id": obj.get("session_id"),
            "chatbot_id": obj.get("chatbot_id"),
            "flow_id": obj.get("flow_id"),
            "workspace_id": obj.get("workspace_id"),
            "created_at": obj.get("created_at"),
            "last_msg_at": obj.get("last_msg_at"),
            "msg_count": obj.get("msg_count"),
            "credits": obj.get("credits"),
            "chatbot_name": obj.get("chatbot_name"),
            "flow_name": obj.get("flow_name"),
            "tags": obj.get("tags"),
            "duration": obj.get("duration"),
            "ipaddress": obj.get("ipaddress"),
            "url": obj.get("url")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.bool_char import BoolChar
from flowhunt.models.google_ads_action_type import GoogleAdsActionType
from typing import Optional, Set
from typing_extensions import Self

class GoogleAdsCustomerResponse(BaseModel):
    """
    GoogleAdsCustomerResponse
    """ # noqa: E501
    workspace_id: StrictStr = Field(description="Workspace ID")
    customer_id: StrictStr = Field(description="Google Ads Customer ID")
    customer_name: StrictStr = Field(description="Google Ads Customer Name")
    language_code: StrictStr = Field(description="Language Code")
    country: StrictStr = Field(description="Country Code")
    min_queries: StrictInt = Field(description="Minimum Queries")
    cluster_strength: StrictInt = Field(description="Cluster Strength")
    min_impressions: StrictInt = Field(description="Minimum Impressions")
    min_clicks: StrictInt = Field(description="Minimum Clicks")
    process_negative_keywords: Optional[BoolChar] = None
    last_update: Optional[datetime] = None
    next_update: Optional[datetime] = None
    cron_settings: Optional[StrictStr] = None
    action_type: GoogleAdsActionType = Field(description="Action Type")
    ga_measurement_id: Optional[StrictStr] = None
    ga_api_secret: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["workspace_id", "customer_id", "customer_name", "language_code", "country", "min_queries", "cluster_strength", "min_impressions", "min_clicks", "process_negative_keywords", "last_update", "next_update", "cron_settings", "action_type", "ga_measurement_id", "ga_api_secret"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GoogleAdsCustomerResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if process_negative_keywords (nullable) is None
        # and model_fields_set contains the field
        if self.process_negative_keywords is None and "process_negative_keywords" in self.model_fields_set:
            _dict['process_negative_keywords'] = None

        # set to None if last_update (nullable) is None
        # and model_fields_set contains the field
        if self.last_update is None and "last_update" in self.model_fields_set:
            _dict['last_update'] = None

        # set to None if next_update (nullable) is None
        # and model_fields_set contains the field
        if self.next_update is None and "next_update" in self.model_fields_set:
            _dict['next_update'] = None

        # set to None if cron_settings (nullable) is None
        # and model_fields_set contains the field
        if self.cron_settings is None and "cron_settings" in self.model_fields_set:
            _dict['cron_settings'] = None

        # set to None if ga_measurement_id (nullable) is None
        # and model_fields_set contains the field
        if self.ga_measurement_id is None and "ga_measurement_id" in self.model_fields_set:
            _dict['ga_measurement_id'] = None

        # set to None if ga_api_secret (nullable) is None
        # and model_fields_set contains the field
        if self.ga_api_secret is None and "ga_api_secret" in self.model_fields_set:
            _dict['ga_api_secret'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GoogleAdsCustomerResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "workspace_id": obj.get("workspace_id"),
            "customer_id": obj.get("customer_id"),
            "customer_name": obj.get("customer_name"),
            "language_code": obj.get("language_code"),
            "country": obj.get("country"),
            "min_queries": obj.get("min_queries"),
            "cluster_strength": obj.get("cluster_strength"),
            "min_impressions": obj.get("min_impressions"),
            "min_clicks": obj.get("min_clicks"),
            "process_negative_keywords": obj.get("process_negative_keywords"),
            "last_update": obj.get("last_update"),
            "next_update": obj.get("next_update"),
            "cron_settings": obj.get("cron_settings"),
            "action_type": obj.get("action_type"),
            "ga_measurement_id": obj.get("ga_measurement_id"),
            "ga_api_secret": obj.get("ga_api_secret")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_cron_create_request import FlowCronCreateRequest

class TestFlowCronCreateRequest(unittest.TestCase):
    """FlowCronCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowCronCreateRequest:
        """Test FlowCronCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowCronCreateRequest`
        """
        model = FlowCronCreateRequest()
        if include_optional:
            return FlowCronCreateRequest(
                flow_id = '',
                status = 'E',
                input_text = '',
                variables = {
                    'key' : null
                    },
                interval_settings = '',
                cron_name = ''
            )
        else:
            return FlowCronCreateRequest(
                flow_id = '',
                status = 'E',
                interval_settings = '',
                cron_name = '',
        )
        """

    def testFlowCronCreateRequest(self):
        """Test FlowCronCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TransactionType(str, Enum):
    """
    TransactionType
    """

    """
    allowed enum values
    """
    G = 'G'
    K = 'K'
    V = 'V'
    S = 'S'
    T = 'T'
    D = 'D'
    M = 'M'
    F = 'F'
    I = 'I'
    C = 'C'
    A = 'A'
    Y = 'Y'
    E = 'E'
    X = 'X'
    P = 'P'
    W = 'W'
    O = 'O'
    N = 'N'
    FT_I = 'FT_I'
    DDG = 'DDG'
    CGD = 'CGD'
    CGS = 'CGS'
    RGS = 'RGS'
    UGS = 'UGS'
    IGI = 'IGI'
    TR = 'TR'
    FAT_GC = 'FAT_GC'
    CE_GC = 'CE_GC'
    VE_GC = 'VE_GC'
    CWP = 'CWP'
    DE_GC = 'DE_GC'
    AC_HS = 'AC_HS'
    GC_HS = 'GC_HS'
    UC_HS = 'UC_HS'
    SC_HS = 'SC_HS'
    CNM_HS = 'CNM_HS'
    CNE = 'CNE'
    SE = 'SE'
    GE = 'GE'
    ALE = 'ALE'
    RLE = 'RLE'
    CPS = 'CPS'
    CS_GS = 'CS_GS'
    IG_API = 'IG_API'
    FA = 'FA'
    HC = 'HC'
    CNE = 'CNE'
    MCP = 'MCP'
    SEQUENTIAL_AGENT = 'SEQUENTIAL_AGENT'
    SELF_MANAGED_AGENT = 'SELF_MANAGED_AGENT'
    TOOL_ARXIV = 'TOOL_ARXIV'
    TOOL_REDDIT = 'TOOL_REDDIT'
    TOOL_WIKIPEDIA = 'TOOL_WIKIPEDIA'
    TOOL_DALL_E = 'TOOL_DALL_E'
    TOOL_YOUTUBE_SEARCH = 'TOOL_YOUTUBE_SEARCH'
    TOOL_IFTTT_WEBHOOK = 'TOOL_IFTTT_WEBHOOK'
    TOOL_PUBMED = 'TOOL_PUBMED'
    TOOL_STACK_EXCHANGE = 'TOOL_STACK_EXCHANGE'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TransactionType from a JSON string"""
        return cls(json.loads(json_str))


